<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="17"/>
        <location filename="../mainwindow.cpp" line="71"/>
        <source>MX Repo Manager</source>
        <translation>MX Gestor de Repositórios</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="32"/>
        <location filename="../mainwindow.cpp" line="548"/>
        <source>Select the APT repository that you want to use:</source>
        <translation>Seleccionar o repositório APT a usar:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="59"/>
        <source>MX repos</source>
        <translation>Repositórios MX</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="84"/>
        <source>Select fastest MX repo for me</source>
        <translation>Seleccionar automaticamente o repositório mais rápido </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="110"/>
        <source>search</source>
        <translation>procurar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="168"/>
        <source>Debian repos</source>
        <translation>Repositórios Debian</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="180"/>
        <source>Select fastest Debian repo for me</source>
        <translation>Seleccionar automaticamente o repositório mais rápido</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="229"/>
        <source>Individual sources</source>
        <translation>Origens individuais</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="248"/>
        <source>Restore original APT sources</source>
        <translation>Restaurar as origens APT iniciais</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="330"/>
        <source>Display help </source>
        <translation>Mostrar ajuda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="333"/>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="340"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="385"/>
        <source>About this application</source>
        <translation>Sobre esta aplicação</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="388"/>
        <source>About...</source>
        <translation>Sobre...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="395"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="411"/>
        <source>Quit application</source>
        <translation>Sair da aplicação</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="414"/>
        <source>Close</source>
        <translation>Fechar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="421"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="440"/>
        <source>Apply</source>
        <translation>Aplicar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="125"/>
        <location filename="../mainwindow.cpp" line="389"/>
        <location filename="../mainwindow.cpp" line="692"/>
        <source>Success</source>
        <translation>Êxito</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="126"/>
        <location filename="../mainwindow.cpp" line="390"/>
        <location filename="../mainwindow.cpp" line="696"/>
        <source>Your new selection will take effect the next time sources are updated.</source>
        <translation>A nova escolha terá efeito na próxima vez que as origens forem atualizadas.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="222"/>
        <source>Lists</source>
        <translation>Listas</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="222"/>
        <source>Sources (checked sources are enabled)</source>
        <translation>Origens (as origens marcadas estão activadas)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="392"/>
        <location filename="../mainwindow.cpp" line="599"/>
        <location filename="../mainwindow.cpp" line="609"/>
        <location filename="../mainwindow.cpp" line="627"/>
        <location filename="../mainwindow.cpp" line="644"/>
        <location filename="../mainwindow.cpp" line="652"/>
        <location filename="../mainwindow.cpp" line="671"/>
        <location filename="../mainwindow.cpp" line="677"/>
        <location filename="../mainwindow.cpp" line="759"/>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="392"/>
        <source>Could not change the repo.</source>
        <translation>Não foi possível alterar o repositório.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="413"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="419"/>
        <source>Please wait...</source>
        <translation>Aguardar...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="461"/>
        <source>About %1</source>
        <translation>Sobre o %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="462"/>
        <source>Version: </source>
        <translation>Versão: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="464"/>
        <source>Program for choosing the default APT repository</source>
        <translation>Programa para escolher o repositório APT pré-definido</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="466"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Direitos de autor (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="467"/>
        <source>%1 License</source>
        <translation>Licença do %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="481"/>
        <source>%1 Help</source>
        <translation>Ajuda do %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="489"/>
        <source>Warning</source>
        <translation>Aviso</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="490"/>
        <source>You have selected MX Test Repo. It&apos;s not recommended to leave it enabled or to upgrade all the packages from it.</source>
        <translation>Foi seleccionado o Repositório MX Test (~/mx/testrepo/~). Não é recomendado que este repositório seja deixado activado nem que todos os pacotes actualizáveis sejam actualizados a partir das versões deste repositório.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="493"/>
        <source>A safer option is to install packages individually with MX Package Installer.</source>
        <translation>A opção mais segura é instalar um pacote de cada vez com o MX Instalador de Pacotes.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="550"/>
        <source>Select the APT repository and sources that you want to use:</source>
        <translation>Seleccionar o repositório APT e as origens a usar:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="599"/>
        <source>netselect-apt could not detect fastest repo.</source>
        <translation>O netselect-apt não consegue detectar qual é o repositório mais rápido.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="609"/>
        <location filename="../mainwindow.cpp" line="627"/>
        <source>Could not detect fastest repo.</source>
        <translation>Não foi possível detectar qual é o repositório mais rápido.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="644"/>
        <source>Can&apos;t figure out if this app is running on antiX or MX</source>
        <translation>Impossível detectar se o sistema em uso é antiX ou MX</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="653"/>
        <source>MX version not detected or out of range: </source>
        <translation>Versão do MX não detectada ou fora do leque de alcance</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="671"/>
        <source>Could not download original APT files.</source>
        <translation>Não foi possível transferir os ficheiros APT originais.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="677"/>
        <source>Could not unzip downloaded file.</source>
        <translation>Não foi possível descompactar o ficheiro transferido.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="687"/>
        <source>Enabling AHS</source>
        <translation>A activar o AHS</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="687"/>
        <source>Do you use AHS (Advanced Hardware Stack) repo?</source>
        <translation>É usado o repositório AHS (Advanced Hardware Stack)?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="693"/>
        <source>Original APT sources have been restored to the release status. User added source files in /etc/apt/sources.list.d/ have not been touched.</source>
        <translation>As origens APT originais foram restauradas para o estado de lançamento. Os ficheiros de origens adicionados pelo utilizador a /etc/apt/sources.list.d/ não foram alterados.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="760"/>
        <source>There was an error writing file: %1. Please check if you have enough free space on your drive</source>
        <translation>Houve um erro ao gravar o ficheiro: %1. Verifique se tem espaço livre suficiente na sua unidade</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="52"/>
        <source>License</source>
        <translation>Licença</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="53"/>
        <location filename="../about.cpp" line="62"/>
        <source>Changelog</source>
        <translation>Registo de alterações</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="54"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="74"/>
        <source>&amp;Close</source>
        <translation>&amp;Fechar</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="67"/>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="68"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>O utilizador parece ser o root; para usar este programa, sair e voltar a entrar como utilizador normal.</translation>
    </message>
</context>
</TS>
